==> jc-1.4.0.tar.gz: java/nio/channels/Pipe__24SourceChannel.h <==
// public abstract class java.nio.channels.Pipe$SourceChannel

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2a71a1103f7cdc8f java_nio_channels_Pipe__24SourceChannel
// @dep_class b95b712f8b955018 java_nio_channels_SelectableChannel
// @dep_class b39240b3676cb59b java_nio_channels_spi_AbstractInterruptibleChannel
// @dep_class 9d3bd8ebcf76e5ce java_nio_channels_spi_AbstractSelectableChannel

// header file dependencies
// @dep_header java_nio_channels_spi_AbstractSelectableChannel

#include "java/nio/channels/spi/AbstractSelectableChannel.h"

#ifndef _JC_java_nio_channels_Pipe__24SourceChannel_H_
#define _JC_java_nio_channels_Pipe__24SourceChannel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_spi_SelectorProvider$object;

// Typedefs
typedef struct _jc_java_nio_channels_Pipe__24SourceChannel$sub_refs	_jc_java_nio_channels_Pipe__24SourceChannel$sub_refs;
typedef struct _jc_java_nio_channels_Pipe__24SourceChannel$sub_nonrefs	_jc_java_nio_channels_Pipe__24SourceChannel$sub_nonrefs;
typedef struct _jc_java_nio_channels_Pipe__24SourceChannel$refs	_jc_java_nio_channels_Pipe__24SourceChannel$refs;
typedef struct _jc_java_nio_channels_Pipe__24SourceChannel$nonrefs	_jc_java_nio_channels_Pipe__24SourceChannel$nonrefs;
typedef struct _jc_java_nio_channels_Pipe__24SourceChannel$object	_jc_java_nio_channels_Pipe__24SourceChannel$object;

typedef const struct _jc_java_nio_channels_Pipe__24SourceChannel$vmethods	_jc_java_nio_channels_Pipe__24SourceChannel$vmethods;
typedef const struct _jc_java_nio_channels_Pipe__24SourceChannel$vtable	_jc_java_nio_channels_Pipe__24SourceChannel$vtable;
typedef const struct _jc_java_nio_channels_Pipe__24SourceChannel$vtype	_jc_java_nio_channels_Pipe__24SourceChannel$vtype;

// Constructors
extern void _jc_java_nio_channels_Pipe__24SourceChannel$method$_init$21bbe82c9df5d674(_jc_env *, struct _jc_java_nio_channels_Pipe__24SourceChannel$object *, struct _jc_java_nio_channels_spi_SelectorProvider$object *);

// Virtual methods
extern jint _jc_java_nio_channels_Pipe__24SourceChannel$method$validOps$2ee4dac018721573(_jc_env *, struct _jc_java_nio_channels_Pipe__24SourceChannel$object *);

// Virtual method descriptors
extern _jc_method _jc_java_nio_channels_Pipe__24SourceChannel$method_info$validOps$2ee4dac018721573;

// Virtual methods structure
struct _jc_java_nio_channels_Pipe__24SourceChannel$vmethods {
	jint	(*validOps$2ee4dac018721573)(_jc_env *, struct _jc_java_nio_channels_Pipe__24SourceChannel$object *);
};

// Vtable
struct _jc_java_nio_channels_Pipe__24SourceChannel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$vmethods	java_nio_channels_spi_AbstractInterruptibleChannel;
	_jc_java_nio_channels_SelectableChannel$vmethods	java_nio_channels_SelectableChannel;
	_jc_java_nio_channels_spi_AbstractSelectableChannel$vmethods	java_nio_channels_spi_AbstractSelectableChannel;
	_jc_java_nio_channels_Pipe__24SourceChannel$vmethods	java_nio_channels_Pipe__24SourceChannel;
};

// Vtype
struct _jc_java_nio_channels_Pipe__24SourceChannel$vtype {
	_jc_type			type;
	_jc_java_nio_channels_Pipe__24SourceChannel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_Pipe__24SourceChannel$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_Pipe__24SourceChannel$refs {
    _jc_java_nio_channels_Pipe__24SourceChannel$sub_refs	java_nio_channels_Pipe__24SourceChannel;
    _jc_java_nio_channels_spi_AbstractSelectableChannel$sub_refs	java_nio_channels_spi_AbstractSelectableChannel;
    _jc_java_nio_channels_SelectableChannel$sub_refs	java_nio_channels_SelectableChannel;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_refs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_Pipe__24SourceChannel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_Pipe__24SourceChannel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_nonrefs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_nio_channels_SelectableChannel$sub_nonrefs	java_nio_channels_SelectableChannel;
    _jc_java_nio_channels_spi_AbstractSelectableChannel$sub_nonrefs	java_nio_channels_spi_AbstractSelectableChannel;
    _jc_java_nio_channels_Pipe__24SourceChannel$sub_nonrefs	java_nio_channels_Pipe__24SourceChannel;
};

// Object instance structure
struct _jc_java_nio_channels_Pipe__24SourceChannel$object {
	_jc_java_nio_channels_Pipe__24SourceChannel$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_Pipe__24SourceChannel$vtype	*vtype;
	_jc_java_nio_channels_Pipe__24SourceChannel$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_Pipe__24SourceChannel$vtype _jc_java_nio_channels_Pipe__24SourceChannel$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_Pipe__24SourceChannel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_Pipe__24SourceChannel$class_object;

#endif	/* _JC_java_nio_channels_Pipe__24SourceChannel_H_ */

==> jc-1.4.6.tar.gz: java/nio/channels/Pipe__24SourceChannel.h <==
// public abstract class java.nio.channels.Pipe$SourceChannel

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2a71a1103f7cdc8f java_nio_channels_Pipe__24SourceChannel
// @dep_class b95b712f8b955018 java_nio_channels_SelectableChannel
// @dep_class b39240b3676cb59b java_nio_channels_spi_AbstractInterruptibleChannel
// @dep_class 9d3bd8ebcf76e5ce java_nio_channels_spi_AbstractSelectableChannel

// header file dependencies
// @dep_header java_nio_channels_spi_AbstractSelectableChannel

#include "java/nio/channels/spi/AbstractSelectableChannel.h"

#ifndef _JC_java_nio_channels_Pipe__24SourceChannel_H_
#define _JC_java_nio_channels_Pipe__24SourceChannel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_channels_spi_SelectorProvider$object;

// Typedefs
typedef struct _jc_java_nio_channels_Pipe__24SourceChannel$sub_refs	_jc_java_nio_channels_Pipe__24SourceChannel$sub_refs;
typedef struct _jc_java_nio_channels_Pipe__24SourceChannel$sub_nonrefs	_jc_java_nio_channels_Pipe__24SourceChannel$sub_nonrefs;
typedef struct _jc_java_nio_channels_Pipe__24SourceChannel$refs	_jc_java_nio_channels_Pipe__24SourceChannel$refs;
typedef struct _jc_java_nio_channels_Pipe__24SourceChannel$nonrefs	_jc_java_nio_channels_Pipe__24SourceChannel$nonrefs;
typedef struct _jc_java_nio_channels_Pipe__24SourceChannel$object	_jc_java_nio_channels_Pipe__24SourceChannel$object;

typedef const struct _jc_java_nio_channels_Pipe__24SourceChannel$vmethods	_jc_java_nio_channels_Pipe__24SourceChannel$vmethods;
typedef const struct _jc_java_nio_channels_Pipe__24SourceChannel$vtable	_jc_java_nio_channels_Pipe__24SourceChannel$vtable;
typedef const struct _jc_java_nio_channels_Pipe__24SourceChannel$vtype	_jc_java_nio_channels_Pipe__24SourceChannel$vtype;

// Constructors
extern void _jc_java_nio_channels_Pipe__24SourceChannel$method$_init$21bbe82c9df5d674(_jc_env *, struct _jc_java_nio_channels_Pipe__24SourceChannel$object *, struct _jc_java_nio_channels_spi_SelectorProvider$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_nio_channels_Pipe__24SourceChannel$method$validOps$2ee4dac018721573(_jc_env *, struct _jc_java_nio_channels_Pipe__24SourceChannel$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_nio_channels_Pipe__24SourceChannel$method_info$validOps$2ee4dac018721573;

// Virtual methods structure
struct _jc_java_nio_channels_Pipe__24SourceChannel$vmethods {
	jint	(*validOps$2ee4dac018721573)(_jc_env *, struct _jc_java_nio_channels_Pipe__24SourceChannel$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_nio_channels_Pipe__24SourceChannel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_channels_spi_AbstractInterruptibleChannel$vmethods	java_nio_channels_spi_AbstractInterruptibleChannel;
	_jc_java_nio_channels_SelectableChannel$vmethods	java_nio_channels_SelectableChannel;
	_jc_java_nio_channels_spi_AbstractSelectableChannel$vmethods	java_nio_channels_spi_AbstractSelectableChannel;
	_jc_java_nio_channels_Pipe__24SourceChannel$vmethods	java_nio_channels_Pipe__24SourceChannel;
};

// Vtype
struct _jc_java_nio_channels_Pipe__24SourceChannel$vtype {
	_jc_type			type;
	_jc_java_nio_channels_Pipe__24SourceChannel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_Pipe__24SourceChannel$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_Pipe__24SourceChannel$refs {
    _jc_java_nio_channels_Pipe__24SourceChannel$sub_refs	java_nio_channels_Pipe__24SourceChannel;
    _jc_java_nio_channels_spi_AbstractSelectableChannel$sub_refs	java_nio_channels_spi_AbstractSelectableChannel;
    _jc_java_nio_channels_SelectableChannel$sub_refs	java_nio_channels_SelectableChannel;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_refs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_Pipe__24SourceChannel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_Pipe__24SourceChannel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_channels_spi_AbstractInterruptibleChannel$sub_nonrefs	java_nio_channels_spi_AbstractInterruptibleChannel;
    _jc_java_nio_channels_SelectableChannel$sub_nonrefs	java_nio_channels_SelectableChannel;
    _jc_java_nio_channels_spi_AbstractSelectableChannel$sub_nonrefs	java_nio_channels_spi_AbstractSelectableChannel;
    _jc_java_nio_channels_Pipe__24SourceChannel$sub_nonrefs	java_nio_channels_Pipe__24SourceChannel;
};

// Object instance structure
struct _jc_java_nio_channels_Pipe__24SourceChannel$object {
	_jc_java_nio_channels_Pipe__24SourceChannel$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_Pipe__24SourceChannel$vtype	*vtype;
	_jc_java_nio_channels_Pipe__24SourceChannel$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_Pipe__24SourceChannel$vtype _jc_java_nio_channels_Pipe__24SourceChannel$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_Pipe__24SourceChannel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_Pipe__24SourceChannel$class_object;

#endif	/* _JC_java_nio_channels_Pipe__24SourceChannel_H_ */
